@@ -88,6 +88,8 @@ typedef struct {
     { N_("speaker"), FALSE }, \
     { N_("volume"), FALSE }, \
     { N_("master"), FALSE }, \
+    { N_("digital output"), FALSE }, \
+    { N_("capture"), FALSE }, \
     { NULL, FALSE } \
   }
 
